// This script is used only when testing Director.
// The tests must already be loaded into the Director JavaScript script
// members.

Test.Harness.Director.runTests(
  "async_js",
  "simple_js",
  "more_js",
  "bad_plan_js",
  "buffer_js",
  "builder_js",
  "circular_data_js",
  "create_js",
  "curr_test_js",
  "diag_js",
  "details_js",
  "jsan.js",
  "output_js",
  "harness_js"
);